@@ -469,7 +469,7 @@ class CameraConfigInputSettings(TypedDict):
     urls: NotRequired[list[str]]
 
 
-class BaseCameraConfig(TypedDict):
+class CameraConfig(TypedDict):
     name: str
     nativeId: Optional[str]
     isCloud: Optional[bool]
@@ -477,12 +477,8 @@ class BaseCameraConfig(TypedDict):
     info: Optional[CameraInformation]
 
 
-class CameraConfig(BaseCameraConfig):
-    sources: list[CameraConfigInputSettings]
-
-
-class PartialCameraConfig(BaseCameraConfig, total=False):
-    sources: NotRequired[list[CameraConfigInputSettings]]
+class PartialCameraConfig(CameraConfig, total=False):
+    pass
 
 
 class RTSPUrlOptions(TypedDict, total=False):
